import type { NuxtConfig } from '@nuxt/schema'

const IS_DEV = process.env.NODE_ENV === 'development'

const NUXT_BACKEND_URL = process.env.NUXT_BACKEND_URL

const graphqlMiddleware: NuxtConfig['graphqlMiddleware'] = {
  serverApiPrefix: '/api/graphql',
  autoImportPatterns: [
    'pages/**/*.{gql,graphql}',
    'components/**/*.{gql,graphql}',
    'composables/**/*.{gql,graphql}',
    'app/**/*.{gql,graphql}',
    'helpers/**/*.{gql,graphql}',
    'queries/**/*.{gql,graphql}',
    'stores/**/*.{gql,graphql}',
    'server/**/*.{gql,graphql}',
    'sites/**/*.{gql,graphql}',
    '!node_modules',
    'node_modules/vuepal/dist/runtime/components/AdminToolbar/query.adminToolbar.graphql',
    'node_modules/vuepal/dist/runtime/components/LocalTasks/query.localTasks.graphql',
    'node_modules/vuepal/dist/runtime/composables/useDrupalRoute/fragment.drupalRoute.graphql',
    'node_modules/@blokkli/editor/dist/runtime/adapter/**/*.{gql,graphql}',
  ],
  documents: [],
  outputDocuments: true,
  autoInlineFragments: true,
  downloadSchema: IS_DEV,
  graphqlEndpoint: `${NUXT_BACKEND_URL}/graphql`, // If we have Multisite Setup we need to use NUXT_HOST here.
  codegenConfig: {
    enumPrefix: true,
    avoidOptionals: false,
    preResolveTypes: true,
    maybeValue: 'T',
    flattenGeneratedTypes: false,
    exportFragmentSpreadSubTypes: false,
    skipTypeNameForRoot: true,
    inlineFragmentTypes: 'combine',
    dedupeFragments: true,
    nonOptionalTypename: false,
    skipTypename: true,
  },
  codegenSchemaConfig: {
    urlSchemaOptions: {
      headers: {
        'x-drupal-graphql-token': process.env.DRUPAL_GRAPHQL_TOKEN ?? '',
      },
    },
  },
}

export default graphqlMiddleware
